@@ -63,7 +63,7 @@ import traceback
 from cryptography.hazmat.primitives import hashes, padding, serialization
 from cryptography.hazmat.primitives.asymmetric import padding as asymmetric_padding
 
-__version__ = "0.2.16"
+__version__ = "0.2.17"
 
 logger = logging.getLogger(__name__)
 
@@ -568,7 +568,7 @@ class Honeypot:
                 event_props = {}
 
             # Automatically add email tracking if request is available
-            if self.request and hasattr(self.request, 'user'):
+            if self.request and hasattr(self.request, 'user') and "email" not in event_props:
                 event_props.update({
                     "email": getattr(self.request.user, 'email', '') if self.request.user else ""
                 })
